@@ -1,23 +1,17 @@
 use super::*;
+mod attachment;
 mod builder;
+mod clip;
 mod display;
+mod origin;
+mod repeat;
 #[cfg(test)]
 mod test;
 
-/// https://developer.mozilla.org/zh-CN/docs/Web/CSS/background-attachment
-#[derive(Copy, Clone, Debug)]
-enum AttachmentKind {
-    Scroll,
-    Fixed,
-    Local,
-    Global(CssBehavior),
-}
-
-#[doc = include_str ! ("aspect-ratio.md")]
-#[derive(Copy, Clone, Debug)]
-pub struct TailwindBackgroundAttachment {
-    kind: AttachmentKind,
-}
+pub use self::{
+    attachment::TailwindBackgroundAttachment, clip::TailwindBackgroundClip, origin::TailwindBackgroundOrigin,
+    repeat::TailwindBackgroundRepeat,
+};
 
 #[doc = include_str ! ("aspect-ratio.md")]
 #[derive(Clone, Debug)]
@@ -25,6 +19,12 @@ pub struct TailwindBackgroundColor {
     pub(crate) color: ColorResolver,
 }
 
+// https://tailwindcss.com/docs/background-origin
+#[derive(Clone, Debug)]
+pub struct TailwindBackgroundPosition {
+    position: TailwindObjectPosition,
+}
+
 #[doc = include_str ! ("aspect-ratio.md")]
 #[derive(Clone, Debug)]
 pub struct TailwindBackgroundBrightness {
