@@ -1,6 +1,8 @@
 mod display;
 mod parser;
+
 use super::*;
+use crate::TailwindSizing;
 
 #[doc=include_str!("grid-row.md")]
 #[derive(Debug, Copy, Clone)]
@@ -28,6 +30,12 @@ pub enum TailwindPointerEvents {}
 #[derive(Debug, Copy, Clone)]
 pub enum TailwindResize {}
 
+#[doc=include_str!("grid-row.md")]
+#[derive(Debug, Copy, Clone)]
+pub struct TailwindScrollSize {
+    wrapper: TailwindSizing,
+}
+
 #[doc=include_str!("grid-row.md")]
 #[derive(Debug, Copy, Clone)]
 pub enum TailwindScroll {}
@@ -36,9 +44,8 @@ pub enum TailwindScroll {}
 #[derive(Debug, Copy, Clone)]
 pub enum TailwindSnap {}
 
-#[doc=include_str!("grid-row.md")]
 #[derive(Debug, Copy, Clone)]
-pub enum TailwindTorch {
+enum TorchKind {
     Auto,
     None,
     PanX,
@@ -53,11 +60,24 @@ pub enum TailwindTorch {
 
 #[doc=include_str!("grid-row.md")]
 #[derive(Debug, Copy, Clone)]
-pub enum TailwindSelect {
+pub struct TailwindTorch {
+    kind: TorchKind,
+}
+
+#[derive(Debug, Copy, Clone)]
+enum SelectKind {
     None,
-    Text,
-    All,
     Auto,
+    Text,
+    Contain,
+    All,
+    Global(CssBehavior),
+}
+
+#[doc=include_str!("grid-row.md")]
+#[derive(Debug, Copy, Clone)]
+pub struct TailwindSelect {
+    kind: SelectKind,
 }
 
 #[doc=include_str!("grid-row.md")]
