@@ -50,10 +50,8 @@ impl Display for TailwindBreakLayout {
 
 impl TailwindInstance for TailwindBreakLayout {
     fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
-        let class = self.kind.to_string();
-        let breaking = self.info.to_string();
         css_attributes! {
-            class => breaking
+            self.kind => self.info
         }
     }
 }
@@ -192,7 +190,7 @@ impl TailwindInstance for TailwindClear {
     }
 }
 
-impl Display for IsolationKind {
+impl Display for Isolation {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             Self::Isolate => f.write_str("left"),
@@ -204,8 +202,8 @@ impl Display for IsolationKind {
 impl Display for TailwindIsolation {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self.kind {
-            IsolationKind::Isolate => f.write_str("isolate"),
-            IsolationKind::Auto => f.write_str("isolation-auto"),
+            Isolation::Isolate => f.write_str("isolate"),
+            Isolation::Auto => f.write_str("isolation-auto"),
         }
     }
 }
@@ -218,7 +216,7 @@ impl TailwindInstance for TailwindIsolation {
     }
 }
 
-impl Display for ObjectFitKind {
+impl Display for ObjectFit {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             Self::Contain => f.write_str("contain"),
@@ -252,7 +250,7 @@ impl Display for TailwindObjectPosition {
 
 impl TailwindInstance for TailwindObjectPosition {}
 
-impl Display for OverflowKind {
+impl Display for Overflow {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             Self::Auto => f.write_str("auto"),
@@ -266,43 +264,93 @@ impl Display for OverflowKind {
 
 impl Display for TailwindOverflow {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
+        match self.axis {
+            None => write!(f, "overflow-{}", self.kind),
+            Some(true) => write!(f, "overflow-x-{}", self.kind),
+            Some(false) => write!(f, "overflow-y-{}", self.kind),
+        }
     }
 }
 
 impl TailwindInstance for TailwindOverflow {
-    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
-        todo!()
+    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+        let class = match self.axis {
+            None => "overflow",
+            Some(true) => "overflow-x",
+            Some(false) => "overflow-y",
+        };
+        css_attributes! {
+            class => self
+        }
     }
 }
 
-impl Display for OverscrollKind {
+impl Display for Overscroll {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
+        match self {
+            Self::Auto => f.write_str("auto"),
+            Self::Contain => f.write_str("contain"),
+            Self::None => f.write_str("none"),
+        }
     }
 }
 
 impl Display for TailwindOverscroll {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
+        match self.axis {
+            None => write!(f, "overscroll-{}", self.kind),
+            Some(true) => write!(f, "overscroll-x-{}", self.kind),
+            Some(false) => write!(f, "overscroll-y-{}", self.kind),
+        }
     }
 }
 
 impl TailwindInstance for TailwindOverscroll {
-    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
-        todo!()
+    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+        let class = match self.axis {
+            None => "overscroll-behavior",
+            Some(true) => "overscroll-behavior-x",
+            Some(false) => "overscroll-behavior-y",
+        };
+        css_attributes! {
+            class => self
+        }
+    }
+}
+
+impl Display for PositionKind {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Self::Static => f.write_str("static"),
+            Self::Fixed => f.write_str("fixed"),
+            Self::Absolute => f.write_str("absolute"),
+            Self::Relative => f.write_str("relative"),
+            Self::Sticky => f.write_str("sticky"),
+        }
     }
 }
 
 impl Display for TailwindPosition {
+    #[inline]
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        todo!()
+        Display::fmt(&self.kind, f)
     }
 }
 
 impl TailwindInstance for TailwindPosition {
-    fn attributes(&self, ctx: &TailwindBuilder) -> BTreeSet<CssAttribute> {
-        todo!()
+    fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
+        css_attributes! {
+            "position" => self
+        }
+    }
+}
+
+impl Display for Visibility {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        match self {
+            Self::Visible => f.write_str("visible"),
+            Self::Invisible => f.write_str("hidden"),
+        }
     }
 }
 
@@ -320,26 +368,23 @@ impl TailwindInstance for TailwindVisibility {
 
 impl Display for TailWindZIndex {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
-        match self {
-            Self::Positive(n) => write!(f, "z-{}", n),
-            Self::Negative(n) => write!(f, "-z-{}", n),
-            Self::Auto => write!(f, "z-auto"),
+        match self.kind {
+            ZIndex::Auto => write!(f, "w-auto"),
+            ZIndex::Unit(n) if self.neg => write!(f, "-w-{}", n),
+            ZIndex::Unit(n) => write!(f, "w-{}", n),
         }
     }
 }
 
 impl TailwindInstance for TailWindZIndex {
     fn attributes(&self, _: &TailwindBuilder) -> BTreeSet<CssAttribute> {
-        match self {
-            Self::Positive(n) => css_attributes! {
-                "z-index" => &n.to_string()
-            },
-            Self::Negative(n) => css_attributes! {
-                "z-index" => &(-(*n as isize)).to_string()
-            },
-            Self::Auto => css_attributes! {
-                "z-index" => "auto"
-            },
+        let index = match self.kind {
+            ZIndex::Auto => "auto".to_string(),
+            ZIndex::Unit(n) if self.neg => format!("-{}", n),
+            ZIndex::Unit(n) => format!("{}", n),
+        };
+        css_attributes! {
+            "z-index" => index
         }
     }
 }
