@@ -20,8 +20,8 @@ use std::{
     fmt::{Debug, Display, Formatter, Write},
     str::FromStr,
 };
-use tailwind_ast::{parse_f32, parse_f_percent, parse_fraction, parse_i_px_maybe, parse_integer};
+use tailwind_ast::{parse_fraction, parse_i_px_maybe, parse_integer};
 use tailwind_error::{
-    nom::{branch::alt, bytes::complete::tag, combinator::opt, sequence::tuple, IResult},
+    nom::{branch::alt, IResult},
     Result,
 };
