@@ -2,8 +2,8 @@ use super::*;
 
 impl TailwindScale {
     // https://tailwindcss.com/docs/scale
-    pub fn parse(input: &[&str], arbitrary: &str, axis: Option<bool>, neg: bool) -> Result<Self> {
-        debug_assert!(arbitrary.is_empty(), "forbidden arbitrary");
+    pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary, axis: Option<bool>, neg: bool) -> Result<Self> {
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary");
         match input {
             [n] => Ok(Self { neg, scale: parse_usize(n)?, axis }),
             _ => syntax_error!("Unknown scale instructions: {}", input.join("-")),
@@ -13,8 +13,8 @@ impl TailwindScale {
 
 impl TailwindRotate {
     // https://tailwindcss.com/docs/rotate
-    pub fn parse(input: &[&str], arbitrary: &str, neg: bool) -> Result<Self> {
-        debug_assert!(arbitrary.is_empty(), "forbidden arbitrary");
+    pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary, neg: bool) -> Result<Self> {
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary");
         match input {
             [n] => Ok(Self { neg, deg: parse_usize(n)? }),
             _ => syntax_error!("Unknown rotate instructions: {}", input.join("-")),
@@ -24,8 +24,8 @@ impl TailwindRotate {
 
 impl TailwindSkew {
     // https://tailwindcss.com/docs/skew
-    pub fn parse(input: &[&str], arbitrary: &str, axis: bool, neg: bool) -> Result<Self> {
-        debug_assert!(arbitrary.is_empty(), "forbidden arbitrary");
+    pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary, axis: bool, neg: bool) -> Result<Self> {
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary");
         match input {
             [n] => Ok(Self { neg, deg: parse_usize(n)?, axis }),
             _ => syntax_error!("Unknown rotate instructions: {}", input.join("-")),
