@@ -3,7 +3,7 @@ use super::*;
 impl TailwindDuration {
     /// https://tailwindcss.com/docs/transition-duration
     pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary in duration");
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after duration");
         match input {
             [n] => Ok(Self { ms: parse_usize(n)? }),
             _ => syntax_error!("Unknown duration instructions: {}", input.join("-")),
@@ -14,7 +14,7 @@ impl TailwindDuration {
 impl TailwindDelay {
     /// https://tailwindcss.com/docs/transition-delay
     pub fn parse(input: &[&str], arbitrary: &TailwindArbitrary) -> Result<Self> {
-        debug_assert!(arbitrary.is_none(), "forbidden arbitrary in duration");
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after duration");
         match input {
             [n] => Ok(Self { ms: parse_usize(n)? }),
             _ => syntax_error!("Unknown delay instructions: {}", input.join("-")),
