@@ -44,16 +44,16 @@ impl TailwindInstruction {
             ["relative"] => TailwindPosition::Relative.boxed(),
             ["sticky"] => TailwindPosition::Sticky.boxed(),
             // https://tailwindcss.com/docs/top-right-bottom-left
-            ["inset", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
-            ["top", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
-            ["right", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
-            ["buttom", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
-            ["left", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
+            ["inset", rest @ ..] => todo!(),
+            ["top", rest @ ..] => todo!(),
+            ["right", rest @ ..] => todo!(),
+            ["buttom", rest @ ..] => todo!(),
+            ["left", rest @ ..] => todo!(),
             // https://tailwindcss.com/docs/visibility
             ["visible"] => TailwindVisibility::Visible.boxed(),
             ["invisible"] => TailwindVisibility::Invisible.boxed(),
             // https://tailwindcss.com/docs/z-index
-            ["z", rest @ ..] => TailWindZIndex::parse(rest, self.negative),
+            ["z", rest @ ..] => TailWindZIndex::parse(rest, arbitrary, self.negative)?.boxed(),
             // Flexbox & Grid
             ["basis", rest @ ..] => TailwindBasis::parse(rest, arbitrary)?.boxed(),
             ["flex", rest @ ..] => Self::flex_adaptor(rest, arbitrary)?,
@@ -135,7 +135,7 @@ impl TailwindInstruction {
             ["prose"] => todo!(),
             // Backgrounds System
             // FIXME: https://tailwindcss.com/docs/background-blend-mode
-            ["bg", rest @ ..] => todo!(),
+            ["bg", rest @ ..] => Self::bg_adaptor(rest, arbitrary)?,
             ["from", rest @ ..] => todo!(),
             ["via", rest @ ..] => todo!(),
             ["to", rest @ ..] => todo!(),
@@ -220,6 +220,26 @@ impl TailwindInstruction {
         Ok(out)
     }
     #[inline]
+    fn bg_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
+        let out = match str {
+            // https://tailwindcss.com/docs/background-attachment
+            ["fixed"] => TailwindBackgroundAttachment::Fixed.boxed(),
+            ["local"] => TailwindBackgroundAttachment::Local.boxed(),
+            ["scroll"] => TailwindBackgroundAttachment::Scroll.boxed(),
+            // https://tailwindcss.com/docs/background-clip
+            ["clip", "border"] => TailwindBackgroundClip::Border.boxed(),
+            ["clip", "padding"] => TailwindBackgroundClip::Padding.boxed(),
+            ["clip", "content"] => TailwindBackgroundClip::Content.boxed(),
+            ["clip", "text"] => TailwindBackgroundClip::Text.boxed(),
+            // https://tailwindcss.com/docs/background-origin
+            ["clip", "padding"] => TailwindBackgroundOrigin::Padding.boxed(),
+            ["clip", "content"] => TailwindBackgroundClip::Content.boxed(),
+            ["clip", "text"] => TailwindBackgroundClip::Text.boxed(),
+            _ => return syntax_error!("Unknown border instructions: {}", str.join("-")),
+        };
+        Ok(out)
+    }
+    #[inline]
     fn border_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
         let out = match str {
             // border
@@ -341,11 +361,31 @@ impl TailwindInstruction {
     }
     #[inline]
     fn grid_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        todo!()
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after place");
+        let out = match str {
+            // https://tailwindcss.com/docs/grid-template-rows
+            ["rows", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/grid-auto-flow
+            ["flow", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/place-self
+            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
+            _ => return syntax_error!("Unknown list instructions: {}", str.join("-")),
+        };
+        Ok(out)
     }
     #[inline]
     fn justify_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        todo!()
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
+        let out = match str {
+            // https://tailwindcss.com/docs/justify-content
+            ["content", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/justify-items
+            ["items", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/justify-self
+            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
+            _ => return syntax_error!("Unknown justify instructions: {}", str.join("-")),
+        };
+        Ok(out)
     }
     #[inline]
     fn content_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
@@ -367,7 +407,17 @@ impl TailwindInstruction {
     }
     #[inline]
     fn place_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        todo!()
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after place");
+        let out = match str {
+            // https://tailwindcss.com/docs/place-content
+            ["content", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/place-items
+            ["items", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/place-self
+            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
+            _ => return syntax_error!("Unknown list instructions: {}", str.join("-")),
+        };
+        Ok(out)
     }
     #[inline]
     fn list_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
@@ -387,11 +437,31 @@ impl TailwindInstruction {
     }
     #[inline]
     fn decoration_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        todo!()
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
+        let out = match str {
+            // https://tailwindcss.com/docs/justify-content
+            ["content", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/justify-items
+            ["items", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/justify-self
+            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
+            _ => return syntax_error!("Unknown justify instructions: {}", str.join("-")),
+        };
+        Ok(out)
     }
     #[inline]
     fn backdrop_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
-        todo!()
+        debug_assert!(arbitrary.is_none(), "forbidden arbitrary after justify");
+        let out = match str {
+            // https://tailwindcss.com/docs/justify-content
+            ["content", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/justify-items
+            ["items", rest @ ..] => TailwindListStyle::None.boxed(),
+            // https://tailwindcss.com/docs/justify-self
+            ["self", rest @ ..] => TailwindListStyle::None.boxed(),
+            _ => return syntax_error!("Unknown justify instructions: {}", str.join("-")),
+        };
+        Ok(out)
     }
     #[inline]
     fn table_adaptor(str: &[&str], arbitrary: &TailwindArbitrary) -> Result<Box<dyn TailwindInstance>> {
